namespace efl { namespace image { 
inline ::efl::eolian::return_traits<bool>::type Animated::animated_get() const
{
   Eina_Bool __return_value =  ::efl_image_animated_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Animated::animated_frame_get() const
{
   int __return_value =  ::efl_image_animated_frame_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Animated::animated_frame_set( ::efl::eolian::in_traits<int>::type frame_index) const
{
   Eina_Bool __return_value =  ::efl_image_animated_frame_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(frame_index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Animated::animated_frame_count_get() const
{
   int __return_value =  ::efl_image_animated_frame_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Efl_Image_Animated_Loop_Hint>::type Animated::animated_loop_type_get() const
{
   Efl_Image_Animated_Loop_Hint __return_value =  ::efl_image_animated_loop_type_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Image_Animated_Loop_Hint>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Animated::animated_loop_count_get() const
{
   int __return_value =  ::efl_image_animated_loop_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<double>::type Animated::animated_frame_duration_get( ::efl::eolian::in_traits<int>::type start_frame,  ::efl::eolian::in_traits<int>::type frame_num) const
{
   double __return_value =  ::efl_image_animated_frame_duration_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start_frame)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(frame_num));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
} } 
namespace eo_cxx {
namespace efl { namespace image { 
inline ::efl::eolian::return_traits<bool>::type Animated::animated_get() const
{
   Eina_Bool __return_value =  ::efl_image_animated_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Animated::animated_frame_get() const
{
   int __return_value =  ::efl_image_animated_frame_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Animated::animated_frame_set( ::efl::eolian::in_traits<int>::type frame_index) const
{
   Eina_Bool __return_value =  ::efl_image_animated_frame_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(frame_index));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Animated::animated_frame_count_get() const
{
   int __return_value =  ::efl_image_animated_frame_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<Efl_Image_Animated_Loop_Hint>::type Animated::animated_loop_type_get() const
{
   Efl_Image_Animated_Loop_Hint __return_value =  ::efl_image_animated_loop_type_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Image_Animated_Loop_Hint>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Animated::animated_loop_count_get() const
{
   int __return_value =  ::efl_image_animated_loop_count_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<double>::type Animated::animated_frame_duration_get( ::efl::eolian::in_traits<int>::type start_frame,  ::efl::eolian::in_traits<int>::type frame_num) const
{
   double __return_value =  ::efl_image_animated_frame_duration_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(start_frame)
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(frame_num));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<double>::type>(__return_value);
}
inline efl::image::Animated::operator ::efl::image::Animated() const { return *static_cast< ::efl::image::Animated const*>(static_cast<void const*>(this)); }
inline efl::image::Animated::operator ::efl::image::Animated&() { return *static_cast< ::efl::image::Animated*>(static_cast<void*>(this)); }
inline efl::image::Animated::operator ::efl::image::Animated const&() const { return *static_cast< ::efl::image::Animated const*>(static_cast<void const*>(this)); }
} } }

